/*
 * XdccDownloader - ReplyTest.java - Copyright © 2013 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.irc;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.hasSize;
import static org.hamcrest.Matchers.is;
import static org.hamcrest.Matchers.notNullValue;

import com.google.common.base.Optional;
import org.junit.Test;

/**
 * Tests for {@link Reply}.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class ReplyTest {

	@Test
	public void testParser() {
		Reply reply;

		reply = Reply.parseLine("NOTICE AUTH :*** Processing your connection");
		assertThat(reply, notNullValue());
		assertThat(reply.source(), is(Optional.<Source>absent()));
		assertThat(reply.command(), is("NOTICE"));
		assertThat(reply.parameters(), hasSize(2));
		assertThat(reply.parameters().get(0), is("AUTH"));
		assertThat(reply.parameters().get(1), is("*** Processing your connection"));

		reply = Reply.parseLine(":ParaDMON!services@paraphysics.services PRIVMSG QshelTier :\u0001VERSION\u0001");
		assertThat(reply, notNullValue());
		assertThat(reply.source(), is(Optional.of(Source.parseSource("ParaDMON!services@paraphysics.services"))));
		assertThat(reply.command(), is("PRIVMSG"));
		assertThat(reply.parameters(), hasSize(2));
		assertThat(reply.parameters().get(0), is("QshelTier"));
		assertThat(reply.parameters().get(1), is("\u0001VERSION\u0001"));
	}

}
