package net.pterodactylus.xdcc.core;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.containsInAnyOrder;
import static org.hamcrest.Matchers.instanceOf;
import static org.mockito.Matchers.any;
import static org.mockito.Matchers.anyInt;
import static org.mockito.Matchers.anyString;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.never;
import static org.mockito.Mockito.times;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;

import net.pterodactylus.irc.Connection;
import net.pterodactylus.irc.ConnectionFactory;
import net.pterodactylus.xdcc.core.event.CoreStarted;
import net.pterodactylus.xdcc.core.event.GenericError;
import net.pterodactylus.xdcc.core.event.GenericMessage;
import net.pterodactylus.xdcc.data.Channel;
import net.pterodactylus.xdcc.data.Network;

import com.google.common.eventbus.EventBus;
import org.junit.After;
import org.junit.Before;
import org.junit.Ignore;
import org.junit.Test;
import org.mockito.ArgumentCaptor;

@Ignore("this test completely sucks")
public class CoreTest {

	private static final String TEMP_DIRECTORY = "/tmp";
	private static final String FINAL_DIRECTORY = "/final";
	private final EventBus eventBus = mock(EventBus.class);
	private final ConnectionFactory connectionFactory = mock(ConnectionFactory.class);
	private final Core core =
			new Core(eventBus, connectionFactory, TEMP_DIRECTORY, FINAL_DIRECTORY);
	private final Connection firstConnection = mock(Connection.class);
	private final Connection secondConnection = mock(Connection.class);

	@Before
	public void setupConnections() {
		when(firstConnection.username(anyString())).thenReturn(firstConnection);
		when(secondConnection.username(anyString())).thenReturn(secondConnection);
	}

	@Before
	public void setupConnectionFactory() {
		when(connectionFactory.createConnection("first.net", 6667)).thenReturn(firstConnection);
		when(connectionFactory.createConnection("second.net", 6667)).thenReturn(secondConnection);
	}

	@After
	public void tearDown() {
		core.stopAndWait();
	}

	@Test
	public void startingTheCoreWithAnEmptyNetworkStartsButDoesNotConnect() {
		Network firstNetwork = Network.builder("FirstNet").build();
		Channel firstChannel = new Channel(firstNetwork, "#first");
		core.addChannel(firstChannel);
		core.startAndWait();
		ArgumentCaptor<Object> eventCaptor = ArgumentCaptor.forClass(Object.class);
		verify(eventBus, times(2)).post(eventCaptor.capture());
		assertThat(eventCaptor.getAllValues(), containsInAnyOrder(
				instanceOf(GenericError.class), instanceOf(CoreStarted.class)
		));
		verify(connectionFactory, never()).createConnection(anyString(), anyInt());
	}

	@Test
	public void startingTheCoreConnectsToConfiguredNetworks() {
		Network firstNetwork = Network.builder("FirstNet")
				.addServer()
				.at("first.net")
				.port(6667)
				.endServer()
				.build();
		Channel firstChannel = new Channel(firstNetwork, "#first");
		Network secondNetwork = Network.builder("SecondNet")
				.addServer()
				.at("second.net")
				.port(6667)
				.endServer()
				.build();
		Channel secondChannel = new Channel(secondNetwork, "#second");
		core.addChannel(firstChannel);
		core.addChannel(secondChannel);
		core.startAndWait();
		verify(eventBus).post(any(CoreStarted.class));
		verify(firstConnection).open();
		verify(secondConnection).open();
	}

}
